#pod test courtesy of petdance
#http://use.perl.org/comments.pl?sid=18853&cid=28930

# $Id: 00_load.t,v 1.2 2004/05/15 14:15:04 jonasbn Exp $

use Test::More tests => 1;

BEGIN { use_ok( 'Module::Info::File' ); }
